/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file Bonus.cc
 * Implementation of the Bonus class.
 */

#include <iostream>

#include "Bonus.hh"

/**
 * Constructor.
 * @param sb the sprite base.
 * @param scr the screen surface.
 * @param bckgrnd the background surface.
 * @param vel the initial velocity.
 * @param angle the initial angle.
 */
Bonus::Bonus(SpriteBase* sb, SDL_Surface* scr, SDL_Surface* bckgrnd, 
             float xvel, float yvel, int angle)
    : Sprite(sb, scr, bckgrnd, xvel, yvel, angle)
{
    _counter = BONUS_TIME;
}

/**
 * Destructor.
 */
Bonus::~Bonus()
{}

/**
 * Decrements the time-to-live of the bonus. If we are out of time, 
 * redraws the background.
 * @return @b true if the bonus still exists, @b false if it has expired.
 */
bool Bonus::go()
{
    _counter--;

    if (_counter < 0) {
        update_background();
        return false;
    }

    return true;
}

/**
 * Draws the bonus on the screen at (x, y). Changes the current picture based 
 * on the counter.
 * @param new_x the new x-coordinate.
 * @param new_y the new y-coordinate.
 */
void Bonus::draw(int new_x, int new_y)
{
    SDL_Rect new_rect;

    new_rect.w = _sprite_base->get_width();
    new_rect.h = _sprite_base->get_height();
    new_rect.x = new_x;
    new_rect.y = new_y;

    _picture = _sprite_base->get_images()[_counter % _sprite_base->get_image_count()];

    SDL_BlitSurface(_picture, NULL, _screen, &new_rect);
}
