/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file Ship.hh
 * Interface of the Ship class.
 */

#ifndef SHIP_HH
#define SHIP_HH

#include "Sprite.hh"

/**
 * Class to represent the ship.
 */
class Ship : public Sprite {
public:
    Ship(SpriteBase* base1, SpriteBase* base2, SDL_Surface* scr, SDL_Surface* bckgrnd, 
         float xvel, float yvel, int angle);
    ~Ship();

    const int get_health();
    const int get_state();
    const int get_bullets();
    const int get_max_bullets();
    const int get_score();

    void set_health(int health);
    void set_state(int state);
    void set_bullets(int bullets);
    void set_max_bullets(int max_bullets);
    void set_score(int score);

    void hit(int damage);
    void go();
    void draw(int new_x, int new_y);
    void make_immune();
    void make_unimmune();
    void make_unhyper();
    void make_unshoot();
    void make_hyper();
    void make_shoot();
    void incr_bullets();
    void decr_bullets();
    void give_health(int health);
    void thrust();
    void unthrust();

private:
    int _immune_counter; /**< When this reaches 0, ship is no longer immune. */
    int _shoot_counter; /**< When this reaches 0, ship no longer has supershoot. */
    int _hyper_counter; /**< When this reaches 0, ship no longer has hyperspace. */
    int _health; /**< Remaining health for this ship. */
    int _state; /**< State of the ship. */
    int _bullets; /**< Current number of bullets in the air. */
    int _max_bullets; /**< Maximum number of shootable bullets. */
    int _score; /**< Current score for the player. */
    SpriteBase* _base1; /**< Base for non-thrusting ship. */
    SpriteBase* _base2; /**< Base for thrusting ship. */
};

#endif // SHIP_HH
