/*  Alien Pool
    Copyright (C) 2003  Michael J. Korman <mike@taequin.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @file common.hh
 * Defines various constants.
 */

#ifndef COMMON_HH
#define COMMON_HH

#include <string>

const int NUM_BULLETS = 100; /**< Maximum number of player bullets. */
const int NUM_ALIEN_BULLETS = 500; /**< Maximum number of alien bullets. */

const int PLAYER_CHANGE = 1; /**< Player rate of change. */
const int BULLET_CHANGE = 9; /**< Bullet rate of change. */

/** Ship rotation rate of change. Must be a divisor of 360! */
const int ANGLE_CHANGE = 6;

const int SCREEN_WIDTH = 640; /**< Width of the screen in pixels. */
const int SCREEN_HEIGHT = 480; /**< Height of the screen in pixels. */

const int TICK_INTERVAL = 30; /**< Milliseconds per frame. */

const int BULLET_TTL = 150; /**< Time-to-live of bullets. */

const int PLAYER_HEALTH = 100; /**< Initial health of the player. */
const int PLAYER_IMMUNE_TIME = 100; /**< Amount of time player is immune. */
const int PLAYER_SHOOT_TIME = 500; /**< Amount of time player has supershoot. */
const int PLAYER_HYPER_TIME = 500; /**< Amount of time player has hyperspace. */
const int PLAYER_BULLET_DAMAGE = 5; /**< Damage bullets inflict upon player. */
const int PLAYER_ALIEN_DAMAGE = 10; /**< Damage aliens inflict upon player. */

const int BONUS_TIME = 300; /**< Time-to-live of bonuses. */
const int BONUS_CHANGE = 8; /**< Bonus rate of change. Not currently used. */
const int HEALTH_BONUS_PROB = 1000; /**< Chance health bonus will appear is 1 over this. */
const int HYPER_BONUS_PROB = 1000; /**< Chance hyper bonus will appear is 1 over this. */
const int SHOOT_BONUS_PROB = 1500; /**< Chance shoot bonus will appear is 1 over this. */ 
const int BONUS_HEALTH = 20; /**< Amount of health the health bonus gives. */

/**
 * Possible states of the game.
 */
enum GAME_STATE { 
    GAME_PLAYING,  /**< Game is in progress. */
    GAME_PAUSED, /**< Game is paused. */
    GAME_MENU, /**< Menu is displayed. */
    GAME_SCORES /**< High scores are displayed. */
};

/**
 * Possible states of aliens.
 */
enum ALIEN_STATE { 
    ALIEN_NORMAL, /**< Alien moves autonomously and shoots. */
    ALIEN_DUMB /**< Alien bounces around, doesn't shoot. */
};

/* Possible states of player. */
const int PLAYER_IMMUNE = 1; /**< Ship flickers, player cannot be hurt. */
const int PLAYER_SHOOT_BONUS = 2; /**< Player has the shoot bonus. */
const int PLAYER_HYPER_BONUS = 4; /**< Player has the hyperspace bonus. */

struct ScoreItem {
    char username[255];
    int score;
};

void game_over();
double round_to_int(double x);

#ifdef WIN32
#define DATADIR "data"
#define LOCALSTATEDIR "."
#endif

#endif // COMMON_HH
